*                          MICRON HSPICE MODEL
*
* Disclaimer:    This software code and all associated documentation, comments
*                or other information (collectively "Software") is provided
*                "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*                ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*                INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*                RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*                FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*                SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*                THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*                MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*                RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*                ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*                OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*                EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*                LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*                SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*                OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*                ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*                EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*                Because some jurisdictions prohibit the exclusion or limitation
*                of liability for consequential or incidental damages, the above
*                limitation may not apply to you.
* 
*                Copyright 2006 Micron Technology, Inc. All rights reserved.
*
************** 512Megx4, 256Megx8, 128Megx16 DDR3 SDRAM ***********************
************** Example HSPICE setup file for DQs *****************************

****************************************************************
****                ____                                       *
****       IN/CKD--|    \                                      *
**** Control bits--|     }------PAD--\/\/\/--@@@@--|--PKG_OUT  *
****        ENOUT--|____/    |        R_pkg  L_pkg |           *
****                         |                    ===C_pkg     *
****                  ___    |                     |           *
****                 /  +|---|                    GND          *
****      RCVR_OUT--{   -|-----VREF                            *
****                 \___|-(ENOUT#)                            *
****************************************************************

**** This netlist is for the x4, x8, x16 1Gb DDR3 SDRAM *****************
**** The input signals are IN (input signal) and ENOUT (output enable signal).
**** The input signal must be clocked into the buffer with the CKD signal.
**** ODTEN controls the On-Die Termination enable/disable functionality.
**** The I/O data is available on the signal PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.

**** The .LIB statement selects the following transistor processing corners:

****   typ_1066   - DDR3-800/DDR3-1066 data rate, Typ N, Typ P, Typical die capacitance
****   slow_1066  - DDR3-800/DDR3-1066 data rate, Slow N, Slow P, Maximum die capacitance
****   fast_1066  - DDR3-800/DDR3-1066 data rate, Fast N, Fast P, Minimum die capacitance

****   typ_1333   - DDR3-1333 data rate, Typ N, Typ P, Typical die capacitance
****   slow_1333  - DDR3-1333 data rate, Slow N, Slow P, Maximum die capacitance
****   fast_1333  - DDR3-1333 data rate, Fast N, Fast P, Minimum die capacitance

****   typ_1600   - DDR3-1600 data rate, typ N,  typ P, Typical die capacitance
****   slow_1600  - DDR3-1600 data rate, typ N,  typ P, Maximum die capacitance
****   fast_1600  - DDR3-1600 data rate, Fast N, Fast P, Minimum die capacitance

****   typ_2133   - DDR3-2133 data rate, Fast N, Fast P, Typical die capacitance
****   slow_2133  - DDR3-2133 data rate, Fast N, Fast P, Maximum die capacitance
****   fast_2133  - DDR3-2133 data rate, Fast N, Fast P, Minimum die capacitance


**** To run this simulation, the files "v69a_model.cnr" and "v69a_dqbuff.inc" are
**** required to be in the same directory as this netlist.
**** Temperature settings are: Typical 50C, Slow 110C, Fast 0C

.OPTIONS ACCT OPTS POST GSHUNT=1e-9 
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.005ns '16*per'
**The temperature is for the slow case
.TEMP 110         $Maximum Temperature for industrial Temp devices is 110C   

.LIB "v69a_model.cnr" slow_1066
*.LIB "v69a_model.cnr" slow_1333
*.LIB "v69a_model.cnr" slow_1600
*.LIB "v69a_model.cnr" slow_2133


**** Input signals and power supplies setup
**** Match up typ, min, or max voltages for corner sims
.PARAM  vccq_typ  = 1.500V
.PARAM  vccq_min  = 1.425V
.PARAM  vccq_max  = 1.575V

.PARAM  vccr_typ   = 1.300V
.PARAM  vccr_min   = 1.200V
.PARAM  vccr_max   = 1.400V

.PARAM  vss       = 0.0V
.PARAM  vssq      = 0.0V
.PARAM  gnd       = 0.0V
.PARAM  vtt       = 'vccq/2'
********************************************************************************
.PARAM  vccq      = vccq_min
.PARAM  vccr      = vccr_min
.param  vccp      = 'vccr+2'

******************************************************************************** 
Vvccq   vccq  0  DC = vccq
Vvccr   vccr  0  DC = vccr
Vvssq   vssq  0  DC = vssq
Vvss    vss   0  DC = vss
Vref    vref  0  DC = 'vccq/2' 
Vvtt    vtt   0  DC = 'vccq/2' 
*****************************************************************************
**On-Die Termination is controlled like the Extended Mode Register settings**
*****************************************************************************
**Bit Settings: EMR Bit 9   EMR Bit 6   EMR Bit 2     Function    **
**                  0           0           0         disabled    **
**                  0           0           1         60 ohm ODT  **
**                  0           1           0         120 ohm ODT **
**                  0           1           1         40 ohm ODT  **
**                  1           0           0         20 ohm ODT  **
**                  1           0           1         30 ohm ODT  **
**                  1           1           0         reserved    **
**                  1           1           1         reserved    **
********************************************************************
Vodt_emr9  emr9 0  DC = vss  $ see table above for settings
Vodt_emr6  emr6 0  DC = vss  $ 0 = vss, 1 = vcc
Vodt_emr2  emr2 0  DC = vss
********************************************************************
Vodt_en    odten   0  DC = vss
*Active high ODT enable, set odten to vcc/vss and set the EMR bits to toggle ODT on/off

********************************************************************************
**Output Drive Strength is controlled like the Extended Mode Register settings**
********************************************************************************
**Bit Settings: EMR Bit 5   EMR Bit 1     Drive Strength  **
**                  0           0         40 ohm          **
**                  0           1         34 ohm          **
**                  1           0         reserved        **
**                  1           1         48 ohm          **
************************************************************
Vodt_emr5  emr5 0  DC = vss  $ see table above for settings
Vodt_emr1  emr1 0  DC = vccr  $ 0 = vss, 1 = vccr
************************************************************

Ven     enout 0  DC = vccr
**Active high (vcc) for output, Active low (vss) for input

**Variables to control data input and data clock
.param datarate = 1066E6
*.param datarate = 1333E6
*.param datarate = 1600E6
*.param datarate = 2133E6

.param pulsewidth = `1/datarate - dataslew`
.param clkpw = `1/datarate - dataclkslew`
.param per = `2*(1/datarate)`
.param clkper = `2*(1/datarate)`
.param delay = 1ns
.param dataslew = 50p
.param dataclkslew = 50p
.param delayclk = `delay - clkper/4`

Vin    in     0  LFSR vss vccr delay dataslew dataslew datarate 1 [5 2]

**Vin toggles the DQ at the datarate specified above

Vdclk   clk   0  PULSE vss vccr delayclk dataclkslew dataclkslew clkpw clkper

**The Data Clock times the release of data from IN through the buffer similar to the internal DLL
**The Data Clock should run at the same frequency as the IN signal with a 1/4 clock cycle offset

*IN/CKD/PAD relationship with ENOUT=vcc (X indicates unknown state)
*         ____                ____      _
*IN  ____/    \______________/    \____/
*      ____      ____      ____      ____
*CKD _/    \____/    \____/    \____/
*                ____                ____
*PAD XXXXXXX____/    \______________/


* top cell:  dqbuff
* *********************************************
* Output load circuits:
xi0 PAD  RCVR_OUT  CLK EMR1 EMR2 EMR5 EMR6 EMR9 ENOUT IN  ODTEN VREF vss vccr vccq vssq v69a_dqbuff 

* Refer to the IBIS model for specific package parasitic values.
r_pkg pad net1 R=146e-3
l_pkg net1 pkg_out L=2.31e-9
c_pkg pkg_out vss c=140e-15

rload pkg_out vtt 25

.alter typ
.PARAM  vccq        = vccq_typ
.PARAM  vccr        = vccr_typ
.temp 50

.LIB "v69a_model.cnr" typ_1066
*.LIB "v69a_model.cnr" typ_1333
*.LIB "v69a_model.cnr" typ_1600
*.LIB "v69a_model.cnr" typ_2133


.alter fast
.PARAM  vccq        = vccq_max
.PARAM  vccr         = vccr_max
.temp 0				$Minimum Temperature for Industrial Temp devices is -40C 
.LIB "v69a_model.cnr" fast_1066
*.LIB "v69a_model.cnr" fast_1333
*.LIB "v69a_model.cnr" fast_1600
*.LIB "v69a_model.cnr" fast_2133

.alter

Ven     enout 0  DC = vss

.alter write mode

*Ven     enout 0  DC = vss
Vwrite  pkg_out  0 LFSR vss vccr delay dataslew dataslew datarate 1 [5 2]

.END
